<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use Teknisa\MAN\Services\PromocaoCombinada;
use Teknisa\MAN\Services\PromocaoCombinadaAnali;
use Teknisa\MAN\Services;
use Teknisa\MAN\Utilities;

class RelPromocaoCombinadaSint  {
    protected $dataSourceName = 'vnd71001_relPromocaoCombinadaSint';
    protected $promocaoCombinada;
    protected $utilService;
    
    public function __construct (PromocaoCombinada $promocaoCombinada, Utilities\Util $utilService, PromocaoCombinadaAnali $prodCombAnaliService){
        $this->utilService          = $utilService;
        $this->promocaoCombinada    = $promocaoCombinada;
        $this->prodCombAnaliService = $prodCombAnaliService;
    }
    
    public function getProdPai(Request\Filter $request, Response $response) {
        
        try{
            
            $conditions = $this->utilService->getParamsAsArray($request);
            $this->handleConditions($conditions);
            $response->addDataSet(new DataSet("vnd71001_relPromocaoCombinadaSint", 
            $this->promocaoCombinada->buscaProdPromocao($conditions['CDFILIAL'], $conditions['P_DTINI'], $conditions["P_DTFIM"], $conditions["PRODINI"], $conditions["PRODFIM"], $conditions["NRORG"], $conditions['TMODALIDADE'],  $conditions['MODALIDADE'], $conditions['CDARVPROD'], $conditions['TCDARVPROD'])));
        
            return $response;
                
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function findAnaliReport(Request\Filter $request, Response $response){
        $conditions = $this->utilService->getParamsAsArray($request);
        $resposta = $this->prodCombAnaliService->getReport($conditions);
        $response->addDataSet(new DataSet("vnd71000_relPromCombAnali", $resposta));
    }
    
    private function handleConditions (&$conditions){
        if(!array_key_exists('CDFILIAL', $conditions)) {
            $conditions['CDFILIAL'] = array();
        }
        if(array_key_exists('DTENTRVENDA', $conditions)) {
            $conditions['P_DTINI'] = $conditions['DTENTRVENDA'][0];
            $conditions['P_DTFIM'] = $conditions['DTENTRVENDA'][1];
            unset($conditions['DTENTRVENDA']);
        }
        if( !array_key_exists('PRODINI', $conditions) &&  !array_key_exists('PRODFIM', $conditions) ) {
            $conditions['PRODINI'] = $conditions['PRODFIM'] = null;
        }else if(!array_key_exists('PRODFIM', $conditions) ){
            $conditions['PRODFIM'] = 'zzzzzzzzzz';
        }else{
            $conditions['PRODINI'] = str_replace('%', '', $conditions['PRODINI']);
            $conditions['PRODFIM'] = str_replace('%', '', $conditions['PRODFIM']);
        }
        if( array_key_exists('MODALIDADE', $conditions) ) {
            $conditions['MODALIDADE'] = implode('_', $conditions['MODALIDADE']);
            $conditions['TMODALIDADE'] = 'E';
        }else {
            $conditions['TMODALIDADE'] = 'T';
            $conditions['MODALIDADE'] = '';
        }
        if( array_key_exists('CDARVPROD', $conditions) ) {
            $conditions['CDARVPROD'] = implode('_', $conditions['CDARVPROD']);
            $conditions['TCDARVPROD'] = 'E';
        }else {
            $conditions['TCDARVPROD'] = 'T';
            $conditions['CDARVPROD'] = '';
        }
        return $conditions;
    }
}