<?php

namespace Teknisa\MAN\Services;

use Doctrine\ORM\EntityManager;
use Teknisa\MAN\Utilities;

class RelRoyaltiesEFundoMarketingService {

	public function __construct(EntityManager $entityManager) {
        $this->entityManager = $entityManager;
    }
    
    public function fetchReport($conditions){
        $params = self::buildParams($conditions);
        return $this->entityManager->getConnection()->fetchAll(self::GET_ROYALTIES_E_MARKETING_QRY, $params);
    }
    
    private function buildParams($conditions){
        if(array_key_exists('CDFILIAL', $conditions)){
            $conditions['CDFILIAL'] = implode('_', $conditions['CDFILIAL']);
            $conditions['TCDFILIAL'] = NULL;
        } else{
            $conditions['CDFILIAL'] = NULL;
            $conditions['TCDFILIAL'] = 'T';
        }
        if(array_key_exists('DTENTRVENDA', $conditions)){
            $conditions['DTINI'] = $conditions['DTENTRVENDA'][0];
            $conditions['DTFIN'] = $conditions['DTENTRVENDA'][1];
        }
        $params = array(
            ':P_CDFILIAL' =>  $conditions['CDFILIAL'],
            ':P_TCDFILIAL'=>  $conditions['TCDFILIAL'],
            ':DTVENDAINI' =>  $conditions['DTINI'], 
            ':DTVENDAFIN' =>  $conditions['DTFIN'], 
            ':NRORG'      =>  $conditions['NRORG']
        );
        // print_r($params);
        return $params;
    }
    
    const GET_ROYALTIES_E_MARKETING_QRY = "
    SELECT T.*,
        ROUND(((T.VRPERCROYALT / 100) * T.VRTOTVENDAS), 2) AS VRTOTROYALT,
        ROUND(((T.VRPERCMARKET / 100) * T.VRTOTVENDAS), 2) AS VRTOTMARKET,
        ROUND(((T.VRPERCMARKET / 100) * T.VRTOTVENDAS) + ((T.VRPERCROYALT / 100) * T.VRTOTVENDAS), 2) AS VRTORGERAL
    FROM (SELECT TO_DATE(TO_CHAR(V.DTENTRVENDA, 'DD/MM/YYYY')) AS DTENTRVENDA, TO_DATE(TO_CHAR(V.DTENTRVENDA, 'DD/MM/YYYY')) AS DTENTRVENDALABEL, V.CDFILIAL,(V.CDFILIAL||' - '||V.NMFILIAL) AS LABELUNIDADE, V.NMFILIAL, V.VRPERCROYALT, V.NRORG, V.VRPERCMARKET, 
                 SUM(TRUNC(I.QTPRODVEND * (I.VRUNITVEND + NVL(I.VRUNITVENDCL,0)),2) - NVL(I.VRDESITVEND,0) + NVL(I.VRACRITVEND,0)) AS VRTOTVENDAS        
          FROM ITEMVENDA I
          JOIN (SELECT V.NRSEQVENDA, V.CDCAIXA, V.DTENTRVENDA, FI.CDFILIAL, FI.NMFILIAL, FI.VRPERCROYALT, FI.VRPERCMARKET, V.NRORG
          FROM VENDA V
         INNER JOIN (SELECT DISTINCT F.CDFILIAL, F.NMFILIAL, F.CDCAIXA, F.CDLOJA, 
                                     F.VRPERCROYALT, F.VRPERCMARKET
                       FROM (SELECT DISTINCT F.CDFILIAL, F.NMFILIAL, F.CDCAIXA, F.CDLOJA, 
                                             NVL(P.VRPERCROYALT,0) AS VRPERCROYALT, NVL(P.VRPERCMARKET,0) AS VRPERCMARKET
                             FROM V_FILIALLOJACAIXA F
                             JOIN PARAVEND P
                               ON F.CDFILIAL = P.CDFILIAL
                           WHERE P.IDTPTAXAMARK = '2'
                           UNION 
                             SELECT DISTINCT F.CDFILIAL, F.NMFILIAL, F.CDCAIXA, F.CDLOJA, 
                                             NVL(P.VRPERCROYALT,0) AS VRPERCROYALT, NVL(P.VRPERCMARKET,0) AS VRPERCMARKET
                               FROM V_FILIALLOJACAIXA F
                               JOIN PARAVEND P
                                 ON F.CDFILIAL = P.CDFILIAL
                             WHERE P.IDTPTAXAROYA = '2') F) FI
            ON V.CDFILIAL = FI.CDFILIAL
           AND V.CDCAIXA = FI.CDCAIXA
           AND V.CDLOJA = FI.CDLOJA
         WHERE V.IDSITUVENDA = 'O'
           AND V.DTENTRVENDA BETWEEN :DTVENDAINI AND :DTVENDAFIN
           AND ((INSTR(:P_CDFILIAL, FI.CDFILIAL) <> 0) OR (:P_TCDFILIAL = 'T'))
           AND V.NRORG = :NRORG) V
        ON V.CDFILIAL    = I.CDFILIAL
       AND V.CDCAIXA     = I.CDCAIXA
       AND V.NRSEQVENDA  = I.NRSEQVENDA
       AND V.NRORG  = I.NRORG
    
       GROUP BY V.DTENTRVENDA, V.CDFILIAL, V.NMFILIAL, V.VRPERCROYALT, V.VRPERCMARKET, V.NRORG) T
    ORDER BY T.CDFILIAL, T.DTENTRVENDA
    ";
}